@@ -42,12 +42,28 @@ def set_status(cat, df):
 
 
 def nadlc():
-    return ['angel', 'becky', 'ellis', 'lil-spot', 'olive', 'rue', 'snowball', 'stripe', 'teja', 'zelda', 'zenon', 'zoltan']
+    return [
+        'angel', 'becky', 'ellis', 'lil-spot', 'olive', 'rue', 'snowball',
+        'stripe', 'teja', 'zelda', 'zenon', 'zoltan'
+    ]
 
 
 def roi_behaviors():
-    return ['cumulative_time_in_roi_sec', 'avg_time_in_roi_sec', 'avg_vel_in_roi']
+    return [
+        'cumulative_time_in_roi_sec', 'avg_time_in_roi_sec', 'avg_vel_in_roi'
+    ]
 
 
 def sniff_instances():
-    return ['t3_sniffsaline', 't5_sniffurine', 't7_sniffsaline', 't9_sniffurine']
+    return [
+        't3_sniffsaline', 't5_sniffurine', 't7_sniffsaline', 't9_sniffurine'
+    ]
+
+
+def combined_behaviors():
+    return [
+        'cat', 'infection_status', 'time', 'trial', 'x_cat', 'y_cat',
+        'cat_distance', 'velocity', 'acceleration', 'moving', 'not_moving',
+        'x_cat_loess05', 'y_cat_loess05', 'cat_distance_loess05',
+        'velocity_loess05', 'acceleration_loess05'
+    ]
